@@ -321,7 +321,7 @@ class Client(Singleton):
             
             print('downloading {}...'.format(url))
 
-            cached_resp = self.redis.get(task_id)
+            cached_resp = await self.redis.get(task_id)
 
             if cached_resp is not None and len(cached_resp) > 0:
                 resp = json.loads(cached_resp)
@@ -346,12 +346,12 @@ class Client(Singleton):
                     if time.time() - t >= timeout:
                         break
                     
-                    resp = self.redis.get(task_id)
+                    resp = await self.redis.get(task_id)
                     if resp is not None and len(resp) > 0:
                         resp = json.loads(resp)
                         if resp['ret']:
                             tmp_url = resp['url']
-                            return self.get_from_cloud(path, tmp_url, force_copy, min_size)
+                            return await self.get_from_cloud_async(path, tmp_url, force_copy, min_size)
                     
                     await asyncio.sleep(1/30)
         except Exception as e:
